==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/diagram/UmlDesktop.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

// all is static ... I don't like singleton

class UmlDesktop {
  public:
    static int width();
    static int height();
    static void tocenter(QWidget * who);
    static void limitsize_center(QWidget * who, double max_w, double max_h);
    static void limitsize_move(QWidget * who, double max_w, double max_h,
			       const QPoint & p);
    static void setsize_center(QWidget * who, double pw, double ph);
    static bool fixed();
    
    static void init();
    
  private:
    static int w;
    static int h;
    static QPoint c;
    static bool fixedp;
};

==> bouml_2.7.4.tar.gz: bouml_2.7.4/src/diagram/UmlDesktop.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

// all is static ... I don't like singleton

class UmlDesktop {
  public:
    static int width();
    static int height();
    static void tocenter(QWidget * who);
    static void limitsize_center(QWidget * who, QSize & previous, double max_w, double max_h);
    static void limitsize_move(QWidget * who, QSize & previous, 
			       double max_w, double max_h,
			       const QPoint & p);
    static void setsize_center(QWidget * who, QSize & previous, 
			       double pw, double ph);
    static bool fixed();
    
    static void init();
    
  private:
    static int w;
    static int h;
    static QPoint c;
    static bool fixedp;
};
